# ns3vc

An unofficial package for voice conversion powered by [Amphion](https://github.com/open-mmlab/Amphion)'s NaturalSpeech3 implementation. All credit goes to Amphion.

NOTE: I am not affiliated with Amphion.

## Installation

```
pip install ns3vc
```

## Citations

```bibtex
@misc{ju2024naturalspeech,
      title={NaturalSpeech 3: Zero-Shot Speech Synthesis with Factorized Codec and Diffusion Models}, 
      author={Zeqian Ju and Yuancheng Wang and Kai Shen and Xu Tan and Detai Xin and Dongchao Yang and Yanqing Liu and Yichong Leng and Kaitao Song and Siliang Tang and Zhizheng Wu and Tao Qin and Xiang-Yang Li and Wei Ye and Shikun Zhang and Jiang Bian and Lei He and Jinyu Li and Sheng Zhao},
      year={2024},
      eprint={2403.03100},
      archivePrefix={arXiv},
      primaryClass={eess.AS}
}

@article{zhang2023amphion,
      title={Amphion: An Open-Source Audio, Music and Speech Generation Toolkit}, 
      author={Xueyao Zhang and Liumeng Xue and Yicheng Gu and Yuancheng Wang and Haorui He and Chaoren Wang and Xi Chen and Zihao Fang and Haopeng Chen and Junan Zhang and Tze Ying Tang and Lexiao Zou and Mingxuan Wang and Jun Han and Kai Chen and Haizhou Li and Zhizheng Wu},
      journal={arXiv},
      year={2024},
      volume={abs/2312.09911}
}
```

## License

MIT